@@ -21,12 +21,11 @@ use crate::{
     request_table::ResponseToken,
     routers::Singleton,
     scope,
+    source::{Combined, Source},
 };
 
-pub(crate) use self::source::Source;
-use self::{source::Combined, stats::Stats};
+use self::stats::Stats;
 
-mod source;
 mod stats;
 
 /// An actor execution context.
@@ -393,6 +392,8 @@ impl<C, K, S> Context<C, K, S> {
                 on_first_recv(&mut self.stage, actor);
             }
 
+            // TODO: reset `trace_id` to `None`?
+
             let mailbox_fut = actor.recv();
             pin_mut!(mailbox_fut);
 
